```
Usage: vcd disk create [OPTIONS] <name> <size in bytes>

Options:
  -d, --description <description>
                                  Description of the new disk
  -s, --storage-profile <name>    Name of the Storage Profile to be used for
                                  the new disk.
  -i, --iops <iops>               Iops requirements of the new disk
  -h, --help                      Show this message and exit.

```
